#!/bin/sh

# Regenerate ubuntu-themes tarball without copyrighted trademarks
VERSION=$1
REVISION=$2

FOLDER=light-themes-$VERSION-bzr$REVISION
ARCHIVE=$FOLDER.tar.xz

bzr export $FOLDER/ -r $REVISION lp:ubuntu-themes
pushd $FOLDER/

# Drop useless ubuntu-mobile icon theme
rm -r ubuntu-mobile/

# Drop useless Unity theme
rm -r {Ambiance,Radiance}/unity/

# Rename ubuntu-mono-* icon themes to Monochrome-*
mv ubuntu-mono-dark/ Monochrome-dark/
mv ubuntu-mono-light/ Monochrome-light/
sed -i "s/Name=Ubuntu-Mono-Dark/Name=Monochrome-dark/" Monochrome-dark/index.theme
sed -i "s/Name=Ubuntu-Mono-Light/Name=Monochrome-light/" Monochrome-light/index.theme
sed -i "s/IconTheme=ubuntu-mono/IconTheme=Monochrome/" {Ambiance,Radiance}/index.theme

# Fix cursor theme name in Ambiance/Radiance themes (named "DMZ-White" in
# Ubuntu, "dmz" in Fedora)
sed -i "s/CursorTheme=DMZ-White/CursorTheme=dmz/" {Ambiance,Radiance}/index.theme

# Remove <shadow> and <padding> tags from metacity-theme-1.xml files, not
# supported by GNOME Shell (see
# https://bugs.launchpad.net/ubuntu/+source/gnome-shell/+bug/850060)
sed -i "/<shadow .*\/>/d; /<padding .*\/>/d" {Ambiance,Radiance}/metacity-1/metacity-theme-1.xml

# Remove copyrighted logo icons
rm distributor-logo.png
find Monochrome-*/ LoginIcons                  \
  \(                                           \
        -name "computer.*"                     \
     -o -name "distributor-logo.*"             \
     -o -name "package-supported.*"            \
     -o -name "preferences-system-directory.*" \
     -o -name "start-here.*"                   \
  \) -delete

# Delete dead icon symlinks
find -L . -type l -exec rm {} \;

popd

tar -cJf $ARCHIVE $FOLDER
rm -r $FOLDER
